@@ -20,6 +20,8 @@ enum {
   SPVM_API_C_STACK_INDEX_ARGS_WIDTH = 379,
   SPVM_API_C_STACK_INDEX_CALL_DEPTH = 378,
   SPVM_API_C_STACK_INDEX_ENV = 377,
+  SPVM_API_C_STACK_INDEX_SEED = 376,
+  SPVM_API_C_STACK_INDEX_SEED_INITIALIZED = 375,
 };
 
 /*
@@ -376,4 +378,12 @@ void SPVM_API_set_no_free(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object,
 
 void SPVM_API_print_exception_to_stderr(SPVM_ENV* env, SPVM_VALUE* stack);
 
+SPVM_OBJECT* SPVM_API_dump_object_internal(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object);
+
+int32_t SPVM_API_get_seed(SPVM_ENV* env, SPVM_VALUE* stack);
+
+void SPVM_API_set_seed(SPVM_ENV* env, SPVM_VALUE* stack, int32_t seed);
+
+int32_t SPVM_API_seed_initialized(SPVM_ENV* env, SPVM_VALUE* stack);
+
 #endif
