@@ -897,6 +897,21 @@ int32_t SPVM__Fn__no_free(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Fn__set_no_free(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* object = stack[0].oval;
+  
+  if (!object) {
+    return env->die(env, stack, "The object $object must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  int32_t no_free = stack[1].ival;
+  
+  env->set_no_free(env, stack, object, no_free);
+  
+  return 0;
+}
+
 int32_t SPVM__Fn__get_pointer(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
@@ -1011,3 +1026,43 @@ int32_t SPVM__Fn__pointer_to_string(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Fn__dump_object_internal(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* obj_object = stack[0].oval;
+  
+  void* obj_dump = env->dump_object_internal(env, stack, obj_object);
+  
+  stack[0].oval = obj_dump;
+  
+  return 0;
+}
+
+int32_t SPVM__Fn__get_seed(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t seed = env->get_seed(env, stack);
+  
+  stack[0].ival = seed;
+  
+  return 0;
+}
+
+int32_t SPVM__Fn__set_seed(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t seed = stack[0].ival;
+  
+  env->set_seed(env, stack, seed);
+  
+  return 0;
+}
+
+int32_t SPVM__Fn__seed_initialized(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t seed_initialized = env->seed_initialized(env, stack);
+  
+  stack[0].ival = seed_initialized;
+  
+  return 0;
+}
+
